@@ -10,7 +10,7 @@ from decimal import Decimal as MyDecimal, ROUND_HALF_EVEN
 from functools import wraps
 import inspect
 
-from marshmallow import validate, utils
+from marshmallow import validate, utils, class_registry
 from marshmallow.base import FieldABC, SerializerABC
 from marshmallow.compat import (text_type, OrderedDict, iteritems, total_seconds,
                                 basestring)
@@ -146,13 +146,13 @@ def _get_value_for_keys(keys, obj, default):
 
 
 def _get_value_for_key(key, obj, default):
+    if isinstance(key, basestring) and hasattr(obj, key):
+        return getattr(obj, key)
     if utils.is_indexable_but_not_string(obj):
         try:
             return obj[key]
         except KeyError:
             return default
-    if hasattr(obj, key):
-        return getattr(obj, key)
     return default
 
 
@@ -229,11 +229,12 @@ class Nested(Raw):
     Examples: ::
 
         user = fields.Nested(UserSerializer)
+        user2 = fields.Nested('UserSerializer')  # Equivalent to above
         collaborators = fields.Nested(UserSerializer(many=True, only='id'))
         parent = fields.Nested('self')
 
-    :param Serializer nested: The Serializer class or instance to nest, or
-        "self" to nest the serializer within itself.
+    :param Serializer nested: The Serializer class, instance, or class name (string)
+        to nest, or ``"self"`` to nest the serializer within itself.
     :param tuple exclude: A list or tuple of fields to exclude.
     :param only: A tuple or string of the field(s) to marshal. If ``None``, all fields
         will be marshalled. If a field name (string) is given, only a single
@@ -257,7 +258,7 @@ class Nested(Raw):
         super(Nested, self).__init__(**kwargs)
 
     def __get_fields_to_marshal(self, all_fields):
-        '''Filter all_fields based on self.only and self.exclude.'''
+        """Filter all_fields based on self.only and self.exclude """
         # Default 'only' to all the nested fields
         ret = OrderedDict()
         if all_fields is None:
@@ -286,10 +287,14 @@ class Nested(Raw):
             elif isinstance(self.nested, type) and \
                     issubclass(self.nested, SerializerABC):
                 self.__serializer = self.nested(None, many=self.many)
-            elif self.nested == 'self':
-                self.__serializer = self.parent  # The serializer this fields belongs to
-                # For now, don't allow nesting of depth > 1
-                self.exclude += (self.name, )  # Exclude this field
+            elif isinstance(self.nested, basestring):
+                if self.nested == 'self':
+                    self.__serializer = self.parent  # The serializer this fields belongs to
+                    # For now, don't allow nesting of depth > 1
+                    self.exclude += (self.name, )  # Exclude this field
+                else:
+                    serializer_class = class_registry.get_class(self.nested)
+                    self.__serializer = serializer_class(None, many=self.many)
             else:
                 raise ValueError("Nested fields must be passed a Serializer, not {0}."
                                 .format(self.nested.__class__))
@@ -305,7 +310,12 @@ class Nested(Raw):
             self.__updated_fields = True
             self.serializer._update_fields(nested_obj)
         fields = self.__get_fields_to_marshal(self.serializer.fields)
-        ret = self.serializer.marshal(nested_obj, fields, many=self.many)
+        try:
+            ret = self.serializer.marshal(nested_obj, fields, many=self.many)
+        except TypeError as err:
+            raise TypeError('Could not marshal nested object due to error:\n"{0}"\n'
+                            'If the nested object is a collection, you need to set '
+                            '"many=True".'.format(err))
         # Parent should get any errors stored after marshalling
         if self.serializer.errors:
             self.parent.errors[key] = self.serializer.errors
@@ -329,14 +339,14 @@ def flatten(dictlist, key):
 
 
 class List(Raw):
-    '''A list field.
+    """A list field.
 
     Example: ::
 
         numbers = fields.List(fields.Float)
 
     :param cls_or_instance: A field class or instance.
-    '''
+    """
     def __init__(self, cls_or_instance, **kwargs):
         super(List, self).__init__(**kwargs)
         if isinstance(cls_or_instance, type):
