@@ -9,30 +9,33 @@ import types
 import warnings
 import functools
 
-from marshmallow import base, fields, utils
+from marshmallow import base, fields, utils, class_registry
 from marshmallow.compat import (with_metaclass, iteritems, text_type,
                                 binary_type, OrderedDict)
 
 
+
 class SerializerMeta(type):
-    '''Metaclass for the Serializer class. Binds the declared fields to
+    """Metaclass for the Serializer class. Binds the declared fields to
     a ``_declared_fields`` attribute, which is a dictionary mapping attribute
     names to field objects.
-    '''
+    """
 
     def __new__(mcs, name, bases, attrs):
         attrs['_declared_fields'] = mcs.get_declared_fields(bases, attrs, base.FieldABC)
-        return super(SerializerMeta, mcs).__new__(mcs, name, bases, attrs)
+        new_class = super(SerializerMeta, mcs).__new__(mcs, name, bases, attrs)
+        class_registry.register(name, new_class)
+        return new_class
 
     @classmethod
     def get_declared_fields(mcs, bases, attrs, field_class):
-        '''Return the declared fields of a class as an OrderedDict.
+        """Return the declared fields of a class as an OrderedDict.
 
         :param tuple bases: Tuple of classes the class is subclassing.
         :param dict attrs: Dictionary of class attributes.
         :param type field_class: The base field class. Any class attribute that
             is of this type will be be returned
-        '''
+        """
         declared = [(field_name, attrs.pop(field_name))
                     for field_name, val in list(iteritems(attrs))
                     if utils.is_instance_or_subclass(val, field_class)]
@@ -66,7 +69,7 @@ class SerializerOpts(object):
 
 
 class BaseSerializer(base.SerializerABC):
-    '''Base serializer class with which to define custom serializers.
+    """Base serializer class with which to define custom serializers.
 
     Example usage:
 
@@ -107,7 +110,7 @@ class BaseSerializer(base.SerializerABC):
         instead of failing silently and storing the errors.
     :param bool many: Should be set to ``True`` if ``obj`` is a collection
         so that the object will be serialized to a list.
-    '''
+    """
     TYPE_MAPPING = {
         text_type: fields.String,
         binary_type: fields.String,
@@ -127,7 +130,7 @@ class BaseSerializer(base.SerializerABC):
     OPTIONS_CLASS = SerializerOpts
 
     class Meta(object):
-        '''Options object for a Serializer.
+        """Options object for a Serializer.
 
         Example usage: ::
 
@@ -148,7 +151,7 @@ class BaseSerializer(base.SerializerABC):
             storing them.
         - ``json_module``: JSON module to use. Defaults to the ``json`` module
             in the stdlib.
-        '''
+        """
         pass
 
     def __init__(self, obj=None, extra=None, only=None,
@@ -161,7 +164,7 @@ class BaseSerializer(base.SerializerABC):
         # copy declared fields from metaclass
         self.declared_fields = copy.deepcopy(self._declared_fields)
         self.fields = OrderedDict()
-        self.__data = None
+        self._data = None
         self.obj = obj
         self.many = many
         self.opts = self.OPTIONS_CLASS(self.Meta)
@@ -183,7 +186,7 @@ class BaseSerializer(base.SerializerABC):
             raw_data = self.marshal(self.obj, self.fields, many=self.many)
             if self.extra:
                 raw_data.update(self.extra)
-            self.__data = self.process_data(raw_data)
+            self._data = self.process_data(raw_data)
 
     @classmethod
     def factory(cls, *args, **kwargs):
@@ -264,10 +267,11 @@ class BaseSerializer(base.SerializerABC):
             field_names=field_names)
         if obj_marshallable and self.many:
             try:  # Homogeneous collection
-                obj_dict = utils.to_marshallable_type(obj_marshallable[0],
-                    field_names=field_names)
+                obj_prototype = obj_marshallable[0]
             except IndexError:  # Nothing to serialize
                 return self.declared_fields
+            obj_dict = utils.to_marshallable_type(obj_prototype,
+                field_names=field_names)
         else:
             obj_dict = obj_marshallable
         ret = OrderedDict()
@@ -292,12 +296,12 @@ class BaseSerializer(base.SerializerABC):
     def data(self):
         """The serialized data as an :class:`OrderedDict`.
         """
-        if not self.__data:  # Cache the data
+        if not self._data:  # Cache the data
             raw_data = self.marshal(self.obj, self.fields, many=self.many)
             if self.extra:
                 raw_data.update(self.extra)
-            self.__data = self.process_data(raw_data)
-        return self.__data
+            self._data = self.process_data(raw_data)
+        return self._data
 
     @property
     def json(self):
@@ -317,9 +321,9 @@ class BaseSerializer(base.SerializerABC):
         return data
 
     def to_json(self, *args, **kwargs):
-        '''Return the JSON representation of the data. Takes the same arguments
-        as Pythons built-in ``json.dumps``.
-        '''
+        """Return the JSON representation of the data. Takes the same arguments
+        as Python's built-in ``json.dumps``.
+        """
         ret = self.opts.json_module.dumps(self.data, *args, **kwargs)
         # On Python 2, json.dumps returns bytestrings
         # On Python 3, json.dumps returns unicode
